==> owncloud_7.0.0~rc1%2Bdfsg.orig.tar.bz2: owncloud/apps/activity/l10n/tr.php <==
<?php
$TRANSLATIONS = array(
"Your settings have been updated." => "Ayarlarınız güncellendi.",
"Activity" => "Etkinlik",
"A file or folder has been <strong>shared</strong>" => "Bir dosya veya klasör <strong>paylaşıldı</strong>",
"A new file or folder has been <strong>created</strong> in a shared folder" => "Paylaşılan bir klasörde bir dosya veya klasör <strong>oluşturuldu</strong>",
"A file or folder has been <strong>changed</strong> in a shared folder" => "Paylaşılan bir klasörde bir dosya veya klasör <strong>değiştirildi</strong>",
"A file or folder has been <strong>deleted</strong> from a shared folder" => "Paylaşılan bir klasörden bir dosya veya klasör <strong>silindi</strong>",
"You created %1\$s" => "%1\$s dosyasını oluşturdunuz",
"%2\$s created %1\$s" => "%2\$s, %1\$s dosyasını oluşturdu",
"You changed %1\$s" => "%1\$s dosyasını değiştirdiniz",
"%2\$s changed %1\$s" => "%2\$s, %1\$s dosyasını değiştirdi",
"You deleted %1\$s" => "%1\$s dosyasını sildiniz",
"%2\$s deleted %1\$s" => "%2\$s, %1\$s dosyasını sildi",
"You shared %1\$s with %2\$s" => "%1\$s dosyasını %2\$s ile paylaştınız",
"You shared %1\$s with group %2\$s" => "%1\$s dosyasını %2\$s grubu ile paylaştınız",
"%2\$s shared %1\$s with you" => "%2\$s sizinle %1\$s dosyasını paylaştı",
"You shared %1\$s via link" => "Bağlantı ile %1\$s paylaşımını yaptınız",
"Activity notification" => "Etkinlik bildirimi",
"All Activities" => "Tüm Etkinlikler",
"Activities by you" => "Sizin etkinlikleriniz",
"Activities by others" => "Başkalarının etkinlikleri",
"Shares" => "Paylaşımlar",
"Files" => "Dosyalar",
"%s and %s" => "%s ve %s",
", " => ", ",
"_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_::_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_" => array("%s ve <strong class=\"tooltip\" title=\"%s\">%n daha fazla</strong>","%s ve <strong class=\"tooltip\" title=\"%s\">%n daha fazla</strong>"),
"_%s and %n more_::_%s and %n more_" => array("%s ve %n daha fazla","%s ve %n daha fazla"),
"Hello %s," => "Merhaba %s,",
"You are receiving this email because in the last hour the following things happened at %s" => "Bu e-postayı alma sebebiniz son saatte %s üzerinde aşağıdaki şeylerin gerçekleşmesi:",
"You are receiving this email because in the last day the following things happened at %s" => "Bu e-postayı alma sebebiniz son günde %s üzerinde aşağıdaki şeylerin gerçekleşmesi:",
"You are receiving this email because in the last week the following things happened at %s" => "Bu e-postayı alma sebebiniz son haftada %s üzerinde aşağıdaki şeylerin gerçekleşmesi:",
"* %s" => "* %s",
"You will see a list of events here when you start to use your %s." => "%s kullanmaya başladığınızda burada olayların bir listesini göreceksiniz.",
"No more events to load" => "Yüklenecek başka olay yok",
"Enable RSS feed" => "RSS beslemesini etkinleştir",
"Notifications" => "Bildirimler",
"Mail" => "Posta",
"Stream" => "Akış",
"You need to set up your email address before you can receive notification emails." => "Bildirim e-postalarını almadan önce e-posta adresinizi ayarlamanız gerekiyor.",
"Send emails:" => "E-postaları gönder:",
"Hourly" => "Her saat",
"Daily" => "Her gün",
"Weekly" => "Her hafta",
"Activity feed" => "Etkinlik beslemesi",
"Personal activity feed for %s" => "%s kişisel etkinlik beslemesi"
);
$PLURAL_FORMS = "nplurals=2; plural=(n > 1);";

==> owncloud_7.0.1~rc1%2Bdfsg.orig.tar.bz2: owncloud/apps/activity/l10n/tr.php <==
<?php
$TRANSLATIONS = array(
"Your settings have been updated." => "Ayarlarınız güncellendi.",
"Activity" => "Etkinlik",
"A file or folder has been <strong>shared</strong>" => "Bir dosya veya klasör <strong>paylaşıldı</strong>",
"A new file or folder has been <strong>created</strong>" => "Yeni bir dosya veya klasör <strong>oluşturuldu</strong>",
"A file or folder has been <strong>changed</strong>" => "Bir dosya veya klasör <strong>değiştirildi</strong>",
"A file or folder has been <strong>deleted</strong>" => "Bir dosya veya klasör <strong>silindi</strong>",
"You created %1\$s" => "%1\$s dosyasını oluşturdunuz",
"%2\$s created %1\$s" => "%2\$s, %1\$s dosyasını oluşturdu",
"You changed %1\$s" => "%1\$s dosyasını değiştirdiniz",
"%2\$s changed %1\$s" => "%2\$s, %1\$s dosyasını değiştirdi",
"You deleted %1\$s" => "%1\$s dosyasını sildiniz",
"%2\$s deleted %1\$s" => "%2\$s, %1\$s dosyasını sildi",
"You shared %1\$s with %2\$s" => "%1\$s dosyasını %2\$s ile paylaştınız",
"You shared %1\$s with group %2\$s" => "%1\$s dosyasını %2\$s grubu ile paylaştınız",
"%2\$s shared %1\$s with you" => "%2\$s sizinle %1\$s dosyasını paylaştı",
"You shared %1\$s via link" => "Bağlantı ile %1\$s paylaşımını yaptınız",
"Activity notification" => "Etkinlik bildirimi",
"All Activities" => "Tüm Etkinlikler",
"Activities by you" => "Sizin etkinlikleriniz",
"Activities by others" => "Başkalarının etkinlikleri",
"Shares" => "Paylaşımlar",
"Files" => "Dosyalar",
"%s and %s" => "%s ve %s",
", " => ", ",
"_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_::_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_" => array("%s ve <strong class=\"tooltip\" title=\"%s\">%n daha fazla</strong>","%s ve <strong class=\"tooltip\" title=\"%s\">%n daha fazla</strong>"),
"_%s and %n more_::_%s and %n more_" => array("%s ve %n daha fazla","%s ve %n daha fazla"),
"Hello %s," => "Merhaba %s,",
"You are receiving this email because in the last hour the following things happened at %s" => "Bu e-postayı alma sebebiniz son saatte %s üzerinde aşağıdaki şeylerin gerçekleşmesi:",
"You are receiving this email because in the last day the following things happened at %s" => "Bu e-postayı alma sebebiniz son günde %s üzerinde aşağıdaki şeylerin gerçekleşmesi:",
"You are receiving this email because in the last week the following things happened at %s" => "Bu e-postayı alma sebebiniz son haftada %s üzerinde aşağıdaki şeylerin gerçekleşmesi:",
"* %s" => "* %s",
"You will see a list of events here when you start to use your %s." => "%s kullanmaya başladığınızda burada olayların bir listesini göreceksiniz.",
"No more events to load" => "Yüklenecek başka olay yok",
"Enable RSS feed" => "RSS beslemesini etkinleştir",
"Notifications" => "Bildirimler",
"Mail" => "Posta",
"Stream" => "Akış",
"Notify about my own actions" => "Kendi eylemlerimi bildir",
"You need to set up your email address before you can receive notification emails." => "Bildirim e-postalarını almadan önce e-posta adresinizi ayarlamanız gerekiyor.",
"Send emails:" => "E-postaları gönder:",
"Hourly" => "Her saat",
"Daily" => "Her gün",
"Weekly" => "Her hafta",
"Activity feed" => "Etkinlik beslemesi",
"Personal activity feed for %s" => "%s kişisel etkinlik beslemesi"
);
$PLURAL_FORMS = "nplurals=2; plural=(n > 1);";
